import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Horsepower';
  
  const yValue = d => d.weight;
  const yAxisLabel = 'Weight';
  
  const circleRadius = 10;
  const margin = { top: 50, right: 40, bottom: 70, left: 200 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight])
  	.nice();
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  
  const group = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
   const yAxisG =	group.append('g')
    	.call(yAxis)
  		.selectAll('.domain')
  		.remove();
  
  
    yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('x', 0)
      .attr('y', 0)
      .attr('fill', 'black')
      .text(yAxisLabel);
  
  	group.selectAll('rect').data(data)
    	.enter().append('circle')
      	.attr('cy', d => yScale(yValue(d)))
      	.attr('cx', d => xScale(xValue(d)))
      	.attr('r', circleRadius);
  
  	group.append('text')
   		.attr('class', 'title')
  		.attr('y', -10)
  		.text('Top 10 most populous countries');
  
  
  const xAxisTickFormat = number => 
  	format('.3s')(number)
  		.replace('G','B');

  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight);
  
  
  const xAxisG = group.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
    
    xAxisG.select('.domain').remove();

    xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('x',innerWidth / 2)
      .attr('y', 65)
      .attr('fill', 'black')
      .text(xAxisLabel);
};


csv('https://vizhub.com/tonestar/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
  });
  render(data);
});
